@@ -19,10 +19,13 @@ from sherlockpipe.objectinfo.MissionFfiCoordsObjectInfo import MissionFfiCoordsO
 from sherlockpipe.objectinfo.preparer.MissionFfiLightcurveBuilder import MissionFfiLightcurveBuilder
 from sherlockpipe.objectinfo.preparer.MissionInputLightcurveBuilder import MissionInputLightcurveBuilder
 from sherlockpipe.objectinfo.preparer.MissionLightcurveBuilder import MissionLightcurveBuilder
+from sherlockpipe.objectinfo.InvalidNumberOfSectorsError import InvalidNumberOfSectorsError
 from sherlockpipe.scoring.BasicSignalSelector import BasicSignalSelector
 from sherlockpipe.scoring.SnrBorderCorrectedSignalSelector import SnrBorderCorrectedSignalSelector
 from sherlockpipe.scoring.QuorumSnrBorderCorrectedSignalSelector import QuorumSnrBorderCorrectedSignalSelector
 from sherlockpipe.ois.OisManager import OisManager
+from sherlockpipe.search_zones.HabitableSearchZone import HabitableSearchZone
+from sherlockpipe.search_zones.OptimisticHabitableSearchZone import OptimisticHabitableSearchZone
 from sherlockpipe.star.HabitabilityCalculator import HabitabilityCalculator
 from sherlockpipe.transitresult import TransitResult
 from multiprocessing import Pool
@@ -32,7 +35,12 @@ from scipy import stats
 from wotan import flatten
 from astropy.stats import sigma_clip
 
+
 class Sherlock:
+    """
+    Main SHERLOCK PIPEline class to be used for loading input, setting up the running parameters and launch the
+    analysis of the desired TESS, Kepler, K2 or csv objects light curves.
+    """
     TOIS_CSV_URL = 'https://exofop.ipac.caltech.edu/tess/download_toi.php?sort=toi&output=csv'
     CTOIS_CSV_URL = 'https://exofop.ipac.caltech.edu/tess/download_ctoi.php?sort=ctoi&output=csv'
     KOIS_LIST_URL = 'https://exofop.ipac.caltech.edu/kepler/targets.php?sort=num-pc&page1=1&ipp1=100000&koi1=&koi2='
@@ -63,19 +71,34 @@ class Sherlock:
     ois_manager = OisManager()
     use_ois = False
 
-    def __init__(self, object_infos):
+    def __init__(self, object_infos: list):
+        """
+        Initializes a Sherlock object, loading the OIs from the csvs, setting up the detrend and transit configurations,
+        storing the provided object_infos list and initializing the builders to be used to prepare the light curves for
+        the provided object_infos.
+        @param object_infos: a list of objects information to be analysed
+        @type object_infos: a list of ObjectInfo implementations to be resolved and analysed
+        """
         self.setup_files()
         self.setup_detrend()
         self.setup_transit_adjust_params()
         self.object_infos = object_infos
-        self.lightcurve_builders = {}
-        self.lightcurve_builders[InputObjectInfo] = MissionInputLightcurveBuilder()
-        self.lightcurve_builders[MissionInputObjectInfo] = MissionInputLightcurveBuilder()
-        self.lightcurve_builders[MissionObjectInfo] = MissionLightcurveBuilder()
-        self.lightcurve_builders[MissionFfiIdObjectInfo] = MissionFfiLightcurveBuilder()
-        self.lightcurve_builders[MissionFfiCoordsObjectInfo] = MissionFfiLightcurveBuilder()
+        self.lightcurve_builders = {InputObjectInfo: MissionInputLightcurveBuilder(),
+                                    MissionInputObjectInfo: MissionInputLightcurveBuilder(),
+                                    MissionObjectInfo: MissionLightcurveBuilder(),
+                                    MissionFfiIdObjectInfo: MissionFfiLightcurveBuilder(),
+                                    MissionFfiCoordsObjectInfo: MissionFfiLightcurveBuilder()}
+        self.search_zones_resolvers = {'hz': HabitableSearchZone(),
+                                       'ohz': OptimisticHabitableSearchZone()}
 
     def setup_files(self, results_dir=RESULTS_DIR):
+        """
+        Loads the objects of interest data from the downloaded CSVs.
+        @param results_dir:
+        @type results_dir:
+        @return: the Sherlock object itself
+        @rtype: Sherlock
+        """
         self.results_dir = results_dir
         self.load_ois()
         return self
@@ -83,6 +106,24 @@ class Sherlock:
     def setup_detrend(self, initial_smooth=True, initial_rms_mask=True, initial_rms_threshold=1.5,
                       initial_rms_bin_hours=3, n_detrends=6, detrend_method="biweight", cores=1,
                       auto_detrend_periodic_signals=False, auto_detrend_ratio=1/4, auto_detrend_method="biweight"):
+        """
+        Configures the values for the detrends steps.
+        @param initial_smooth: whether to execute an initial local noise reduction before the light curve analysis
+        @param initial_rms_mask: whether to execute high RMS areas masking before the light curve analysis
+        @param initial_rms_threshold: the high RMS areas limit to be applied multiplied by the RMS median
+        @param initial_rms_bin_hours: the high RMS areas binning
+        @param n_detrends: the number of detrends to be applied to the PDCSAP_FLUX curve for each run.
+        @param detrend_method: the type of algorithm to be used for the detrending
+        @param cores: the number of CPU cores to be used for the detrending process
+        @param auto_detrend_periodic_signals: whether to search for intense periodicities from the LS periodogram and
+        perform an initial detrending based on them.
+        @param auto_detrend_ratio: the factor to apply to the highest periodicity found in the LS periodogram which will
+        be used for the initial detrend.
+        @param auto_detrend_method: the detrend method to be applied with the highest periodicity found in the LS
+        periodogram
+        @return: the Sherlock object itself
+        @rtype: Sherlock
+        """
         if detrend_method not in self.VALID_DETREND_METHODS:
             raise ValueError("Provided detrend method '" + detrend_method + "' is not allowed.")
         if auto_detrend_method not in self.VALID_PERIODIC_DETREND_METHODS:
@@ -105,14 +146,41 @@ class Sherlock:
         self.detrend_plot_axis.append([3,1])
         return self
 
-    def setup_transit_adjust_params(self, max_runs=10, period_protec=10, period_min=0.5, period_max=20, bin_minutes=10,
-                                    run_cores=NUM_CORES, snr_min=5, sde_min=5, fap_max=0.1, mask_mode="mask",
-                                    best_signal_algorithm='border-correct', quorum_strength=1):
+    def setup_transit_adjust_params(self, max_runs=10, min_sectors=1, max_sectors=999999, period_protec=10,
+                                    search_zone=None, period_min=0.5, period_max=20, bin_minutes=10, run_cores=NUM_CORES, snr_min=5,
+                                    sde_min=5, fap_max=0.1, mask_mode="mask", best_signal_algorithm='border-correct',
+                                    quorum_strength=1):
+        """
+        Configures the values to be used for the transit fitting and the main run loop.
+        @param max_runs: the max number of runs to be executed for each object.
+        @param min_sectors: the minimum number of sectors/quarters for an object to be analysed
+        @param max_sectors: the maximum number of sectors/quarters for an object to be analysed
+        @param period_protec: the maximum period to be used to calculate the minimum transit duration
+        @param search_zone: the zone where sherlock should be searching transits for. If set, period_min and period_max
+        are to be ignored because they will be generated for the selected zone.
+        @param period_min: the minimum period to search transits for
+        @param period_max: the maximum period to search transits for
+        @param bin_minutes:
+        @param run_cores: the number of CPU cores to use for the transit fitting
+        @param snr_min: the minimum SNR accepted to continue the analysis for an object
+        @param sde_min: the minimum SDE accepted to continue the analysis for an object
+        @param fap_max: the maximum FAP accepted to continue the analysis for an object
+        @param mask_mode: the way to remove every run-selected transit influence in the light curve. 'mask' and
+        'subtract' are available
+        @param best_signal_algorithm: the way to calculate the best signal for each object run. 'basic', 'border-correct'
+        and 'quorum' are available.
+        @param quorum_strength: if quorum is selected as best_signal_algorithm this value will be used for the votes
+        weight.
+        @return: the Sherlock object itself
+        @rtype: Sherlock
+        """
         if mask_mode not in self.MASK_MODES:
             raise ValueError("Provided mask mode '" + mask_mode + "' is not allowed.")
         if best_signal_algorithm not in self.VALID_SIGNAL_SELECTORS:
             raise ValueError("Provided best signal algorithm '" + best_signal_algorithm + "' is not allowed.")
         self.max_runs = max_runs
+        self.min_sectors = min_sectors
+        self.max_sectors = max_sectors
         self.run_cores = run_cores
         self.mask_mode = mask_mode
         self.period_protec = period_protec
@@ -122,24 +190,41 @@ class Sherlock:
         self.snr_min = snr_min
         self.sde_min = sde_min
         self.fap_max = fap_max
-        self.signal_score_selectors = {}
-        self.signal_score_selectors[self.VALID_SIGNAL_SELECTORS[0]] = BasicSignalSelector()
-        self.signal_score_selectors[self.VALID_SIGNAL_SELECTORS[1]] = SnrBorderCorrectedSignalSelector()
-        self.signal_score_selectors[self.VALID_SIGNAL_SELECTORS[2]] = QuorumSnrBorderCorrectedSignalSelector(quorum_strength)
+        self.search_zone = search_zone
+        self.signal_score_selectors = {self.VALID_SIGNAL_SELECTORS[0]: BasicSignalSelector(),
+                                       self.VALID_SIGNAL_SELECTORS[1]: SnrBorderCorrectedSignalSelector(),
+                                       self.VALID_SIGNAL_SELECTORS[2]: QuorumSnrBorderCorrectedSignalSelector(
+                                           quorum_strength)}
         self.best_signal_algorithm = best_signal_algorithm
         return self
 
     def refresh_ois(self):
+        """
+        Downloads the TOIs, KOIs and EPIC OIs into csv files.
+        @return: the Sherlock object itself
+        @rtype: Sherlock
+        """
         self.ois_manager.update_tic_csvs()
         self.ois_manager.update_kic_csvs()
         self.ois_manager.update_epic_csvs()
         return self
 
     def load_ois(self):
+        """
+        Loads the csv OIs files into memory
+        @return: the Sherlock object itself
+        @rtype: Sherlock
+        """
         self.ois = self.ois_manager.load_ois()
         return self
 
     def filter_hj_ois(self):
+        """
+        Filters the in-memory OIs given some basic filters associated to hot jupiters properties. This method is added
+        as an example
+        @return: the Sherlock object itself
+        @rtype: Sherlock
+        """
         self.use_ois = True
         self.ois = self.ois[self.ois["Disposition"].notnull()]
         self.ois = self.ois[self.ois["Period (days)"].notnull()]
@@ -154,17 +239,34 @@ class Sherlock:
         return self
 
     def filter_ois(self, function):
+        """
+        Applies a function accepting the Sherlock objects of interests dataframe and stores the result into the
+        Sherlock same ois dataframe.
+        @param function: the function to be applied to filter the Sherlock OIs.
+        @return: the Sherlock object itself
+        @rtype: Sherlock
+        """
         self.use_ois = True
         self.ois = function(self.ois)
         return self
 
     def limit_ois(self, offset=0, limit=0):
+        """
+        Limits the in-memory loaded OIs given an offset and a limit (like a pagination)
+        @param offset:
+        @param limit:
+        @return: the Sherlock object itself
+        @rtype: Sherlock
+        """
         if limit == 0:
             limit = len(self.ois.index)
         self.ois = self.ois[offset:limit]
         return self
 
     def run(self):
+        """
+        Entrypoint of Sherlock which launches the main execution for all the input object_infos
+        """
         self.__setup_logging()
         logging.info('SHERLOCK (Searching for Hints of Exoplanets fRom Lightcurves Of spaCe-base seeKers)')
         logging.info('Version %s', self.VERSION)
@@ -175,10 +277,15 @@ class Sherlock:
             self.__run_object(object_info)
 
     def __run_object(self, object_info):
+        """
+        Performs the analysis for one object_info
+        @param object_info: The object to be analysed.
+        @type object_info: ObjectInfo
+        """
+        sherlock_id = object_info.sherlock_id()
+        mission_id = object_info.mission_id()
         try:
-            time, flux, star_info, transits_min_count, cadence = self.__prepare(object_info)
-            sherlock_id = object_info.sherlock_id()
-            mission_id = object_info.mission_id()
+            time, flux, star_info, transits_min_count, cadence, sectors = self.__prepare(object_info)
             id_run = 1
             best_signal_score = 1
             self.report[sherlock_id] = []
@@ -203,6 +310,16 @@ class Sherlock:
                 object_report["period"] = transit_results[signal_selection.curve_index].period
                 object_report["duration"] = transit_results[signal_selection.curve_index].duration * 60 * 24
                 object_report["t0"] = transit_results[signal_selection.curve_index].t0
+                object_report["depth"] = transit_results[signal_selection.curve_index].depth
+                object_report['rp_rs'] = transit_results[signal_selection.curve_index].results.rp_rs
+                real_transit_args = np.argwhere(~np.isnan(transit_results[signal_selection.curve_index]
+                                                          .results.transit_depths))
+                object_report["transits"] = np.array(transit_results[signal_selection.curve_index]
+                                                          .results.transit_times)[real_transit_args.flatten()]
+                object_report["transits"] = ','.join(map(str, object_report["transits"]))
+                object_report["sectors"] = ','.join(map(str, sectors))
+                object_report["ffi"] = isinstance(object_info, MissionFfiIdObjectInfo) or \
+                                       isinstance(object_info, MissionFfiCoordsObjectInfo)
                 if self.ois is not None:
                     existing_period_in_object = self.ois[(self.ois["Object Id"] == mission_id) &
                                                          (0.95 < self.ois["Period (days)"] / object_report["period"]) &
@@ -214,22 +331,24 @@ class Sherlock:
                     object_report["oi"] = ""
                 if best_signal_score == 1:
                     logging.info('New best signal is good enough to keep searching. Going to the next run.')
-                    time, flux = self.__apply_mask_from_transit_results(time, flux, transit_results, signal_selection.curve_index)
+                    time, flux = self.__apply_mask_from_transit_results(time, flux, transit_results,
+                                                                        signal_selection.curve_index)
                     id_run += 1
                     if id_run > self.max_runs:
                         logging.info("Max runs limit of %.0f is reached. Stopping.", self.max_runs)
                 else:
                     logging.info('New best signal does not look very promising. End')
                 self.report[sherlock_id].append(object_report)
-            sherlock_id = object_info.sherlock_id()
             self.__setup_object_report_logging(sherlock_id)
             object_dir = self.__init_object_dir(object_info.sherlock_id())
             logging.info("Listing most promising candidates for ID %s:", sherlock_id)
-            logging.info("%-12s%-8s%-10s%-8s%-8s%-8s%-10s%-14s%-14s%-18s%-20s", "Detrend no.", "Period", "Duration", "T0", "SNR",
-                         "SDE", "FAP", "Border_score", "Matching OI", "Semi-major axis", "Habitability Zone")
+            logging.info("%-12s%-8s%-10s%-8s%-8s%-8s%-8s%-10s%-14s%-14s%-18s%-10s%-18s%-20s", "Detrend no.", "Period",
+                         "Duration", "T0", "Depth", "SNR", "SDE", "FAP", "Border_score", "Matching OI", "Planet radius",
+                         "Rp/Rs", "Semi-major axis", "Habitability Zone")
             if sherlock_id in self.report:
-                candidates_df = pandas.DataFrame(columns=['curve', 'period', 'duration', 't0', 'snr', 'sde', 'fap',
-                                                  'border_score', 'oi', 'a', 'hz'])
+                candidates_df = pandas.DataFrame(columns=['curve', 'period', 'duration', 't0', 'depth', 'snr', 'sde',
+                                                          'fap', 'border_score', 'oi', 'rad_p', 'rp_rs', 'a', 'hz'])
+                i = 1
                 for report in self.report[sherlock_id]:
                     a, habitability_zone = HabitabilityCalculator()\
                         .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, report["period"]) \
@@ -237,26 +356,45 @@ class Sherlock:
                         else "-"
                     report['a'] = a
                     report['hz'] = habitability_zone
-                    logging.info("%-12s%-8.4f%-10.2f%-8.2f%-8.2f%-8.2f%-10.6f%-14.2f%-14s%-18.5f%-20s",
+                    if star_info.radius_assumed:
+                        report['rad_p'] = "-"
+                        report['rp_rs'] = "-"
+                    else:
+                        report['rad_p'] = star_info.radius * math.sqrt(report["depth"] / 1000) / 0.0091577
+                    logging.info("%-12s%-8.4f%-10.2f%-8.2f%-8.3f%-8.2f%-8.2f%-10.6f%-14.2f%-14s%-18.5f%-10.5f%-18.5f%-20s",
                                  report["curve"], report["period"],
-                                 report["duration"], report["t0"], report["snr"], report["sde"], report["fap"],
-                                 report["border_score"], report["oi"], a, habitability_zone)
+                                 report["duration"], report["t0"], report["depth"], report["snr"], report["sde"],
+                                 report["fap"], report["border_score"], report["oi"], report['rad_p'], report['rp_rs'],
+                                 a, habitability_zone)
                     candidates_df = candidates_df.append(report, ignore_index=True)
+                    i = i + 1
                 candidates_df.to_csv(object_dir + "candidates.csv", index=False)
+        except InvalidNumberOfSectorsError as e:
+            logging.exception(str(e))
+            print(e)
+            self.__remove_object_dir(sherlock_id)
         except Exception as e:
             logging.exception(str(e))
             print(e)
 
     def __init_object_dir(self, object_id, clean_dir=False):
         dir = self.results_dir + str(object_id)
-        if clean_dir and os.path.exists(dir) and os.path.isdir(dir):
-            shutil.rmtree(dir, ignore_errors=True)
+        dir = dir.replace(" ", "_")
+        if clean_dir:
+            self.__remove_object_dir(object_id)
         if not os.path.exists(dir):
             os.makedirs(dir)
         return dir + "/"
 
+    def __remove_object_dir(self, object_id):
+        dir = self.results_dir + str(object_id)
+        dir = dir.replace(" ", "_")
+        if os.path.exists(dir) and os.path.isdir(dir):
+            shutil.rmtree(dir, ignore_errors=True)
+
     def __init_object_run_dir(self, object_id, run_no, clean_dir=False):
         dir = self.results_dir + str(object_id) + "/" + str(run_no)
+        dir = dir.replace(" ", "_")
         if clean_dir and os.path.exists(dir) and os.path.isdir(dir):
             shutil.rmtree(dir, ignore_errors=True)
         if not os.path.exists(dir):
@@ -300,30 +438,6 @@ class Sherlock:
         object_dir = self.__setup_object_logging(sherlock_id)
         logging.info('ID: %s', sherlock_id)
         lc, star_info, transits_min_count, sectors, quarters = self.lightcurve_builders[type(object_info)].build(object_info)
-        logging.info('================================================')
-        logging.info('USER DEFINITIONS')
-        logging.info('================================================')
-        if self.detrend_method == "gp":
-            logging.info('Detrend method: Gaussian Process Matern 2/3')
-        else:
-            logging.info('Detrend method: Bi-Weight')
-        logging.info('No of detrend models applied: %s', self.n_detrends)
-        logging.info('Minimum number of transits: %s', transits_min_count)
-        logging.info('Period planet protected: %.1f', self.period_protec)
-        logging.info('Minimum Period (d): %.1f', self.period_min)
-        logging.info('Maximum Period (d): %.1f', self.period_max)
-        logging.info('Binning size (min): %.1f', self.bin_minutes)
-        if object_info.initial_mask is not None:
-            logging.info('Mask: yes')
-        else:
-            logging.info('Mask: no')
-        logging.info('Threshold limit for SNR: %.1f', self.snr_min)
-        logging.info('Threshold limit for SDE: %.1f', self.sde_min)
-        logging.info('Threshold limit for FAP: %.1f', self.fap_max)
-        logging.info('Signal scoring algorithm: %s', self.best_signal_algorithm)
-        if self.best_signal_algorithm == self.VALID_SIGNAL_SELECTORS[2]:
-            logging.info('Quorum algorithm vote strength: %.0f',
-                         self.signal_score_selectors[self.VALID_SIGNAL_SELECTORS[2]].strength)
         if star_info is not None:
             logging.info('================================================')
             logging.info('STELLAR PROPERTIES FOR THE SIGNAL SEARCH')
@@ -342,17 +456,75 @@ class Sherlock:
             logging.info('radius = %.6f', star_info.radius)
             logging.info('radius_min = %.6f', star_info.radius_min)
             logging.info('radius_max = %.6f', star_info.radius_max)
+        if not star_info.radius_assumed and not star_info.mass_assumed and star_info.teff is not None:
+            star_df = pandas.DataFrame(columns=['R_star', 'R_star_lerr', 'R_star_uerr', 'M_star', 'M_star_lerr',
+                                              'M_star_uerr', 'Teff_star', 'Teff_star_lerr', 'Teff_star_uerr'])
+            star_df = star_df.append({'R_star': star_info.radius, 'R_star_lerr': star_info.radius - star_info.radius_min,
+                            'R_star_uerr': star_info.radius_max - star_info.radius,
+                            'M_star': star_info.mass, 'M_star_lerr': star_info.mass - star_info.mass_min,
+                            'M_star_uerr': star_info.mass_max - star_info.mass,
+                            'Teff_star': star_info.teff, 'Teff_star_lerr': 200, 'Teff_star_uerr': 200},
+                           ignore_index=True)
+            star_df.to_csv(object_dir + "params_star.csv", index=False)
+        logging.info('================================================')
+        logging.info('USER DEFINITIONS')
+        logging.info('================================================')
+        if self.detrend_method == "gp":
+            logging.info('Detrend method: Gaussian Process Matern 2/3')
+        else:
+            logging.info('Detrend method: Bi-Weight')
+        logging.info('No of detrend models applied: %s', self.n_detrends)
+        logging.info('Minimum number of transits: %s', transits_min_count)
+        logging.info('Period planet protected: %.1f', self.period_protec)
+        lightcurve_timespan = lc.time[len(lc.time) - 1] - lc.time[0]
+        if self.search_zone is not None and not (star_info.mass_assumed or star_info.radius_assumed):
+            logging.info("Selected search zone: %s. Minimum and maximum periods will be calculated.", self.search_zone)
+            period_min, period_max = self.search_zones_resolvers[self.search_zone].calculate_period_range(star_info)
+            logging.info("Selected search zone periods are [%.2f, %.2f] days", period_min, period_max)
+            if period_min > lightcurve_timespan or period_max > lightcurve_timespan:
+                logging.info("Selected search zone period values are greater than lightcurve dataset. " +
+                             "Defaulting to minimum and maximum input periods.")
+            else:
+                self.period_min = period_min
+                self.period_max = period_max
+        elif self.search_zone is not None:
+            logging.info("Selected search zone was %s but star catalog info was not found or wasn't complete. " +
+                         "Defaulting to minimum and maximum input periods.", self.search_zone)
+        logging.info('Minimum Period (d): %.1f', self.period_min)
+        logging.info('Maximum Period (d): %.1f', self.period_max)
+        logging.info('Binning size (min): %.1f', self.bin_minutes)
+        if object_info.initial_mask is not None:
+            logging.info('Mask: yes')
+        else:
+            logging.info('Mask: no')
+        logging.info('Threshold limit for SNR: %.1f', self.snr_min)
+        logging.info('Threshold limit for SDE: %.1f', self.sde_min)
+        logging.info('Threshold limit for FAP: %.1f', self.fap_max)
+        logging.info('Signal scoring algorithm: %s', self.best_signal_algorithm)
+        if self.best_signal_algorithm == self.VALID_SIGNAL_SELECTORS[2]:
+            logging.info('Quorum algorithm vote strength: %.0f',
+                         self.signal_score_selectors[self.VALID_SIGNAL_SELECTORS[2]].strength)
         if sectors is not None:
+            sectors_count = len(sectors)
             logging.info('================================================')
             logging.info('SECTORS INFO')
             logging.info('================================================')
             logging.info('Sectors : %s', sectors)
             logging.info('No of sectors available: %s', len(sectors))
+            if sectors_count < self.min_sectors or sectors_count > self.max_sectors:
+                raise InvalidNumberOfSectorsError("The object " + sherlock_id + " contains " + str(sectors_count) +
+                                                  " sectors and the min and max selected are [" +
+                                                  str(self.min_sectors) + ", " + str(self.max_sectors) + "].")
         if quarters is not None:
+            sectors_count = len(quarters)
             logging.info('================================================')
             logging.info('QUARTERS INFO')
             logging.info('================================================')
             logging.info('Quarters : %s', quarters)
+            if sectors_count < self.min_sectors or sectors_count > self.max_sectors:
+                raise InvalidNumberOfSectorsError("The object " + sherlock_id + " contains " + str(sectors_count) +
+                                                  " quarters and the min and max selected are [" +
+                                                  str(self.min_sectors) + ", " + str(self.max_sectors) + "].")
         flux = lc.flux
         flux_err = lc.flux_err
         time = lc.time
@@ -365,14 +537,18 @@ class Sherlock:
             self.wl_min[sherlock_id] = 3 * transit_duration  # minimum transit duration
             self.wl_max[sherlock_id] = 20 * transit_duration  # maximum transit duration
         lc = lk.LightCurve(time=time, flux=flux, flux_err=flux_err)
-        lc_df = pandas.DataFrame(columns=['#TBJD', 'flux', 'flux_err'])
-        lc_df['#TBJD'] = lc.time
+        lc_df = pandas.DataFrame(columns=['#time', 'flux', 'flux_err'])
+        lc_df['#time'] = lc.time
         lc_df['flux'] = lc.flux
         lc_df['flux_err'] = lc.flux_err
         lc_df.to_csv(object_dir + "lc.csv", index=False)
         lc = lc.remove_outliers(sigma_lower=float('inf'), sigma_upper=3)  # remove outliers over 3sigma
+        cadence_array = np.diff(lc.time) * 24 * 60
+        cadence_array = cadence_array[~np.isnan(cadence_array)]
+        cadence_array = cadence_array[cadence_array > 0]
+        cadence = np.nanmedian(cadence_array)
         clean_time, flatten_flux, clean_flux_err = self.__clean_initial_flux(object_info, lc.time, lc.flux, lc.flux_err,
-                                                                             star_info)
+                                                                             star_info, cadence)
         lc = lk.LightCurve(time=clean_time, flux=flatten_flux, flux_err=clean_flux_err)
         period = None
         periodogram = lc.to_periodogram(minimum_period=self.wl_min[sherlock_id], oversample_factor=10)
@@ -408,17 +584,15 @@ class Sherlock:
                         (clean_time > mask_range[1] if not math.isnan(mask_range[1]) else False)]
                 clean_time = clean_time[mask]
                 flatten_flux = flatten_flux[mask]
-        cadence_array = np.diff(clean_time) * 24 * 60
-        cadence_array = cadence_array[~np.isnan(cadence_array)]
-        cadence_array = cadence_array[cadence_array > 0]
-        cadence = np.nanmedian(cadence_array)
-        return clean_time, flatten_flux, star_info, transits_min_count, cadence
+        return clean_time, flatten_flux, star_info, transits_min_count, cadence, \
+               sectors if sectors is not None else quarters
 
-    def __clean_initial_flux(self, object_info, time, flux, flux_err, star_info):
+    def __clean_initial_flux(self, object_info, time, flux, flux_err, star_info, cadence):
         clean_time = time
         clean_flux = flux
         clean_flux_err = flux_err
-        if self.initial_smooth or (self.initial_rms_mask and object_info.initial_mask is None):
+        is_short_cadence = round(cadence) <= 5
+        if (is_short_cadence and self.initial_smooth) or (self.initial_rms_mask and object_info.initial_mask is None):
             logging.info('================================================')
             logging.info('INITIAL FLUX CLEANING')
             logging.info('================================================')
@@ -452,13 +626,12 @@ class Sherlock:
             plot_dir = self.__init_object_dir(star_info.object_id)
             fig.savefig(plot_dir + 'High_RMS_Mask_' + str(star_info.object_id) + '.png', dpi=200)
             fig.clf()
-        if self.initial_smooth:
+        if is_short_cadence and self.initial_smooth:
             logging.info('Applying Savitzky-Golay filter')
             clean_flux = savgol_filter(clean_flux, 11, 3)
         return clean_time, clean_flux, clean_flux_err
 
     def __calculate_max_significant_period(self, lc, periodogram):
-        #TODO improve selection of max period
         #max_accepted_period = (lc.time[len(lc.time) - 1] - lc.time[0]) / 4
         max_accepted_period = np.float64(10)
         accepted_power_indexes = np.transpose(np.argwhere(periodogram.power > 0.0008))[0]
@@ -467,7 +640,7 @@ class Sherlock:
         accepted_indexes = [i for i in accepted_period_indexes if i in accepted_power_indexes]
         local_extrema = argrelextrema(periodogram.power[accepted_indexes], np.greater)[0]
         accepted_indexes = np.array(accepted_indexes)[local_extrema]
-        # TODO check whether this fits better
+        # TODO related to https://github.com/franpoz/SHERLOCK/issues/29 check whether this fits better
         #  periodogram.period[np.argmax(periodogram.power)]
         period = None
         if len(accepted_indexes) > 0:
@@ -723,7 +896,7 @@ class Sherlock:
             bin_centers = bin_edges[1:] - bin_width / 2
             bin_size = int(round(bin_width * 60 * 24 * transit_result.period))
             ax2.errorbar(bin_centers, bin_means, yerr=bin_stds / 2, xerr=bin_width / 2, marker='o', markersize=4,
-                         color='teal', alpha=1, linestyle='none', label='Bin size: ' + str(bin_size) + "m")
+                         color='darkorange', alpha=1, linestyle='none', label='Bin size: ' + str(bin_size) + "m")
             ax2.legend(loc="upper right")
         ax3 = plt.gca()
         ax3.axvline(transit_result.period, alpha=0.4, lw=3)
